==> rc-ui-lib-0.1.59.tgz: package/lib/flex/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _ = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Flex', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, null, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 12
            }, "span: 12"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 12
            }, "span: 12")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly when using gutter prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              gutter: 16
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render correctly when gutter prop is array', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              gutter: [16, -16]
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when direction prop is row-reverse', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              direction: "row-reverse"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render correctly when wrap prop is wrap', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              wrap: "wrap"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when using justify prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              justify: "between"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render correctly when using align prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              align: "center"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correctly when using flex prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              align: "center"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              flex: 2
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              flex: 5
            }, "span: 8-2")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when flex prop is decimal', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              align: "center"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              flex: "20px"
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              flex: 5
            }, "span: 8-2")));
            expect((0, _enzymeToJson().default)(wrapper.html())).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});

==> rc-ui-lib-0.2.4.tgz: package/lib/flex/__test__/index.spec.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

function _regenerator() {
  var data = _interopRequireDefault(require("@babel/runtime/regenerator"));

  _regenerator = function _regenerator() {
    return data;
  };

  return data;
}

function _asyncToGenerator2() {
  var data = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

  _asyncToGenerator2 = function _asyncToGenerator2() {
    return data;
  };

  return data;
}

function React() {
  var data = _interopRequireWildcard(require("react"));

  React = function React() {
    return data;
  };

  return data;
}

function _enzyme() {
  var data = require("enzyme");

  _enzyme = function _enzyme() {
    return data;
  };

  return data;
}

function _enzymeToJson() {
  var data = _interopRequireDefault(require("enzyme-to-json"));

  _enzymeToJson = function _enzymeToJson() {
    return data;
  };

  return data;
}

var _ = _interopRequireDefault(require(".."));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

describe('Flex', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
  });
  it('should render correctly', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee() {
    return _regenerator().default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, null, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 12
            }, "span: 12"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 12
            }, "span: 12")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render correctly when using gutter prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee2() {
    return _regenerator().default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              gutter: 16
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render correctly when gutter prop is array', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee3() {
    return _regenerator().default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              gutter: [16, -16]
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render correctly when direction prop is row-reverse', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee4() {
    return _regenerator().default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              direction: "row-reverse"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should render correctly when wrap prop is wrap', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee5() {
    return _regenerator().default.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              wrap: "wrap"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should render correctly when using justify prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee6() {
    return _regenerator().default.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              justify: "between"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should render correctly when using align prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee7() {
    return _regenerator().default.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              align: "center"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-2"), /*#__PURE__*/React().createElement(_.default.Item, {
              span: 8
            }, "span: 8-3")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should render correctly when using flex prop', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee8() {
    return _regenerator().default.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              align: "center"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              flex: 2
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              flex: 5
            }, "span: 8-2")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should render correctly when flex prop is decimal', /*#__PURE__*/(0, _asyncToGenerator2().default)( /*#__PURE__*/_regenerator().default.mark(function _callee9() {
    return _regenerator().default.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = (0, _enzyme().mount)( /*#__PURE__*/React().createElement(_.default, {
              align: "center"
            }, /*#__PURE__*/React().createElement(_.default.Item, {
              flex: "20px"
            }, "span: 8-1"), /*#__PURE__*/React().createElement(_.default.Item, {
              flex: 5
            }, "span: 8-2")));
            expect((0, _enzymeToJson().default)(wrapper)).toMatchSnapshot();

          case 2:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
});
